# Analysis of Ecological Data: Exploratory and Euclidean Methods in Environmental Sciences (**ade4**) <img src="man/figures/logo.svg" align="right" />
[![CRAN_Release_Badge](http://www.r-pkg.org/badges/version-ago/ade4)](http://cran.r-project.org/package=ade4)
[![CRAN Downloads](https://cranlogs.r-pkg.org/badges/ade4)](https://cran.r-project.org/package=ade4)
[![R-CMD-check](https://github.com/adeverse/ade4/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/adeverse/ade4/actions/workflows/R-CMD-check.yaml)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

## 	Presentation

**ade4** is a software developed in the Biometry and Evolutionary Biology Lab (UMR 5558) - University Lyon 1 for the **D**ata **A**nalysis of **E**cological and **E**nvironmental data in the framework of **E**uclidean **E**xploratory methods, hence the name **ade4**.

**ade4** is a package for the [**R** software](https://www.r-project.org) since 2002. It contains functions for exploratory multivariate data analysis and graphical display, many numerical data sets and bibliographic references. Simple one-table methods are described in [Chessel et al. (2004)](http://pbil.univ-lyon1.fr/JTHome/ref/ade4-Rnews.pdf). Two-table and K-table methods are described in [Dray et al. (2007)](http://pbil.univ-lyon1.fr/ade4/article/rnews2/rnews2.pdf). The theory of the duality diagram and its implementation in ade4 are discussed in [Dray et Dufour (2007)](http://pbil.univ-lyon1.fr/ade4/article/jss/jss.pdf).

A book in the *Springer Series in Statistics* collection, [**"Multivariate Analysis of Ecological Data with ade4"**](http://adeverse.github.io/ade4/articles/book.html) presents the package. The examples and the graphs in this book can be [**reproduced online here**](https://lbbe-shiny.univ-lyon1.fr/Reproducible_Research/Book/).

If you use **ade4**, please consider citing [these references](http://adeverse.github.io/ade4/authors.html#citation) !

<p align="center">
<a href="https://www.springer.com/fr/book/9781493988488"><img src="https://pbil.univ-lyon1.fr/members/thioulouse/github/Book.png"  width="207" height="312" border="0" alt=""></a>
<a href="https://pbil.univ-lyon1.fr/members/thioulouse/github/ade4Shiny1.png"><img src="https://pbil.univ-lyon1.fr/members/thioulouse/github/ade4Shiny1.png"  width="40%"></a>
<a href="https://pbil.univ-lyon1.fr/members/thioulouse/github/ade4Shiny2.png"><img src="https://pbil.univ-lyon1.fr/members/thioulouse/github/ade4Shiny2.png"  width="40%"></a>
</p >

<!--
<p align="center">
<img src="https://www.freepnglogos.com/uploads/under-construction-png/under-construction-diy-coming-soon-3.png"  width="20%"> </p >
<p style="text-align:center"> This page is currently under construction. Some sections, such as the FAQ and vignettes, will be completed as time goes on. We apologize for the inconvenience. </p >
-->

## Getting started with **ade4**

### Installing **ade4**

[This page](http://adeverse.github.io/ade4/articles/install.html) explains how to install the **ade4** package in **R**.

### Vignettes

Several vignettes are available to help you get started with **ade4** (more to come soon !):

- [Graphical representation of multivariate data](https://cran.r-project.org/web/packages/adegraphics/vignettes/adegraphics.html)

- [Description of environmental variables structures](http://adeverse.github.io/ade4/articles/ChapEnvVarStruct.html)

- [Description of species structures](http://adeverse.github.io/ade4/articles/ChapSpeciesStruct.html)

- [Taking into account groups of sites](http://adeverse.github.io/ade4/articles/ChapBetGr.html)

- [Description of species-environment relationships](http://adeverse.github.io/ade4/articles/Chap2tables.html)

- [Analysing Changes in Structures](http://adeverse.github.io/ade4/articles/ChapKtables.html)

- [Analysing Changes in Co-structures](http://adeverse.github.io/ade4/articles/Chap2Ktables.html)

### List of function references

You can also find a list of functions available to users on the [reference page](http://adeverse.github.io/ade4/reference/index.html).

### Other resources

Check out the [ade4 book](http://adeverse.github.io/ade4/articles/book.html) and its [shiny application](https://lbbe-shiny.univ-lyon1.fr/Reproducible_Research/Book/) for a complete introduction to the package and to rerun the code present in the book. 
You can also check these [bibliographic references](http://adeverse.github.io/ade4/articles/papers.html) to help you understand **ade4** methods.

Note for nostalgics &#x1F609; : the **old ade4 web site** is still available here: [http://pbil.univ-lyon1.fr/ADE-4/](http://pbil.univ-lyon1.fr/ADE-4/accueil2.php). 

### Using **ade4** online: the Shiny app

Consider giving a try to our shiny app, developed to allow you to run an analysis without having to write your own script: [ade4shiny](https://lbbe-shiny.univ-lyon1.fr/ade4shiny/).
You will be able to download the R script used to generate the results as well as the analyses outputs and graphical representations.

### Getting help: FAQ & Mailing list

You can also check the [FAQ section](http://adeverse.github.io/ade4/articles/faq.html) to check if your question has already been answered or ask for help on the **ade4** mailing list [adelist](https://listes.univ-lyon1.fr/sympa/info/adelist).
\
